%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% --- CREAZIONE DELLA CLASSE --- %%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{Tesi_TorVergata}[25/07/2022, Template Tesi, Facoltà di Economia, Univerisità degli Studi di Roma "Tor Vergata"]


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% --- DEFINIZIONE OPZIONI --- %%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Opzione oneside vs. twoside
\DeclareOption{oneside}{\@twosidefalse  \@mparswitchfalse }
\DeclareOption{twoside}{\@twosidetrue   \@mparswitchtrue
    \def\two{}
}

% Opzione openany vs. openright
\DeclareOption{openany}{\let\cleardoublepage\clearpage}
\DeclareOption{openright}{\ifdefined \two \else \def\cleardoublepage{\clearpage\ifodd\c@page\else \hbox{}\newpage\if@twoside\hbox{}\newpage\fi\fi} \fi
    \def\open{}
}

% Opzione indentation vs. no indentation
\newif\if@indentation 
\DeclareOption{noindent}{\@indentationfalse}
\DeclareOption{indent}{\@indentationtrue} 

% Opzione headline vs. no headline
\newif\if@headline
\DeclareOption{noheadline}{\@headlinefalse}
\DeclareOption{headline}{\@headlinetrue}

% Opzione footline vs. nofootline
\newif\if@footline
\DeclareOption{nofootline}{\@footlinefalse}
\DeclareOption{footline}{\@footlinetrue}

% Opzione elenco delle figure vs. no elenco delle figure
\newif\if@efigure
\DeclareOption{noefigure}{\@efigurefalse}
\DeclareOption{efigure}{\@efiguretrue}

% Opzione elenco delle tabelle vs. no elenco delle tabelle
\newif\if@etabelle
\DeclareOption{noetabelle}{\@etabellefalse}
\DeclareOption{etabelle}{\@etabelletrue}

% Opzione intestazione vs. no intestazione
\newif\if@intest
\DeclareOption{nointest}{\@intestfalse}
\DeclareOption{intest}{\@intesttrue}

\ProcessOptions \relax
\PassOptionsToPackage{leqno}{amsmath}   % numerazione equazioni a sinistra
\LoadClass[12pt]{book}  % tipologia di documento


%%% --- DEFINIZIONE DELLE CONDIZIONI DELLE OPZIONI --- %%%
\@twosidefalse  % oneside (default)

\if@indentation
    \setlength{\parindent}{10pt}
\else
    \setlength{\parindent}{0pt}
\fi
\@indentationfalse  % no indentazione (default)

\RequirePackage{fancyhdr}   % customizzare le intestazioni e i piè di pagina

\if@headline
    \renewcommand{\headrulewidth}{1pt}
\else
    \renewcommand{\headrulewidth}{0pt}
\fi
\@headlinefalse % no headline (default)

\if@footline
    \renewcommand{\footrulewidth}{1pt}
\else
    \renewcommand{\footrulewidth}{0pt}
\fi
\@footlinefalse % no footline (default)

\if@efigure
    \newcommand{\efigure}{
    \ifdefined\open \cleardoublepage \else \clearpage \fi   % if necessario per evitare errori nella numerazione delle pagine nell'intestazione
    \ifdefined\two \cleardoublepage \else \clearpage \fi    % if necessario per evitare errori nella numerazione delle pagine nell'intestazione
    \phantomsection % necessario per far funzionare hyperref
    \addcontentsline{toc}{chapter}{\listfigurename} % aggiunta lista delle figure nell'indice
    \listoffigures} % aggiunta della lista delle figure
\else
    \newcommand{\efigure}{}
\fi
\@efigurefalse  % no elenco delle figure (default) 

\if@etabelle
    \newcommand{\etabelle}{
    \ifdefined\open \cleardoublepage \else \clearpage \fi   % if necessario per evitare errori nella numerazione delle pagine nell'intestazione 
    \ifdefined\two \cleardoublepage \else \clearpage \fi    % if necessario per evitare errori nella numerazione delle pagine nell'intestazione
    \phantomsection % necessario per far funzionare hyperref
    \addcontentsline{toc}{chapter}{\listtablename}  % aggiunta lista delle figure nell'indice
    \listoftables}  % aggiunta della lista delle tabelle
\else
    \newcommand{\etabelle}{}
\fi
\@etabellefalse   % no elenco delle tabelle (default)

\if@intest
    \newcommand{\intest}{% definizione dello stile dell'intestazione e piè di pagina
        \fancyhf{}
        \fancyfoot[C]{\thepage}
        \if@twoside
            \fancyhead[RO]{\slshape\nouppercase{\leftmark}}
            \fancyhead[LO]{\includegraphics[width=3cm]{D. Figure/tor vergata.png}}
            \fancyhead[LE]{\slshape\nouppercase{\leftmark}}
            \fancyhead[RE]{\includegraphics[width=3cm]{D. Figure/tor vergata.png}}
        \else
            \fancyhead[R]{\slshape\nouppercase{\leftmark}}
            \fancyhead[L]{\includegraphics[width=3cm]{D. Figure/tor vergata.png}}
        \fi
    }
\else
    \newcommand{\intest}{
        \fancyhf{}
        \fancyfoot[C]{\thepage}
    }
\fi
\@intestfalse   % no intestazione (default)


%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% --- PACCHETTI  --- %%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%
\RequirePackage[T1]{fontenc}    % font encoding
\RequirePackage[utf8]{inputenc} % input encoding
\RequirePackage[italian]{babel} % lingua italiana
\RequirePackage{newtxtext, newtxmath}   % font simil Times New Roman
\RequirePackage{setspace}   % spaziatura
\RequirePackage{amsmath}    % pacchetto per formula, etc.
\RequirePackage{graphicx}   % pacchetto per figure, etc.
\RequirePackage{pgfplots}   % pacchetto per grafici, etc.
\pgfplotsset{compat=1.18, width=10cm}   % specifica versione di pgfplots
\RequirePackage{titlesec}   % formattazione dei titoli dei capitoli
\RequirePackage[hidelinks,pdfa]{hyperref}   % pacchetto per link esterni e interni (l'indice con i capitoli)
\RequirePackage[authoryear, round]{natbib}  % pacchetto per la bibliografia
\RequirePackage[
  top = 3cm,
  bottom = 3cm,
  left = 3cm,
  right = 2.5cm,
  a4paper
]{geometry} % definizione dei margini


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% --- DEFINIZIONE DI ALCUNE IMPOSTAZIONI --- %%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\renewcommand{\baselinestretch}{1.5}    % interlinea
\titleformat{\chapter} 
    {\normalfont\bfseries\Huge}{\thechapter\hspace{0.5cm}}{10pt}{} % formattazione dei titoli
\setlength{\bibhang}{0pt}   % no indentazione nella bibliografia
\setlength{\headheight}{25pt}   % altezza intestazione
\setcounter{secnumdepth}{3} % modifica del livello di numerazione delle sezioni
\setcounter{tocdepth}{3}    % modifica del livello di numerazione delle sezioni all'interno dell'indice
\raggedbottom

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% --- DEFINIZONE FRONTMATTER --- %%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\renewcommand{\frontmatter}{
    \pagestyle{fancy}
    \intest
    \frontespizio
    \ringraziamenti
    \pagenumbering{roman}   % stile numerazione delle pagine
    \setcounter{page}{0}
    \tableofcontents
    \efigure    % lista delle figure
    \etabelle   % lista delle tabelle
}


\def\universita#1{\def\@universita{#1}}
\def\facolta#1{\def\@facolta{#1}}
\def\corso#1{\def\@corso{#1}}
\def\materia#1{\def\@materia{#1}}
\def\relatore#1{\def\@relatore{#1}}
\def\studente#1{\def\@studente{#1}}
\def\anno#1{\def\@anno{#1}}


%%% --- FRONTESPIZIO --- %%%%
\newcommand{\frontespizio}{
    \thispagestyle{empty}   % stile della pagina (no headers and footers)
    \input{A. Frontmatter/frontespizio}
    \begin{figure}[!t]  % aggiunta del logo di tor vergata
        \centering\includegraphics[width=0.52\textwidth]{D. Figure/tor vergata.png}
    \end{figure}
    \begin{center}  % struttura del frontespizio
    	\vspace{10mm}
        {\LARGE{\bf Università degli Studi di Roma "Tor Vergata"}}\\
    	\vspace{5mm}
    	{\LARGE{\bf Facoltà di Economia}}\\
    	\vspace{11mm}
    	{\Large{\bf Corso di laurea in}}\\
    	\vspace{5mm}
    	{\Large{\bf \@corso}}\\
    	\vspace{28mm}
    	{\LARGE{\bf Tesi in \@materia}}\\
    	\vspace{10mm}
    	{\LARGE{\bf \@title}}
    \end{center}
    \vspace{13mm}
    \begin{minipage}[t]{1\textwidth}
    	{\large{ Il Relatore \hfill \raggedleft{Il laureando}\\ \@relatore \hfill \raggedleft{\@studente}\\}}
    \end{minipage}
    \vspace{17mm}
    \begin{center}
        \large{\bf Anno accademico \@anno }
    \end{center}
    \newpage
}

%%% --- PAGINA PER I RINGRAZIAMENTI --- %%%%
\newcommand{\ringraziamenti}{
  \thispagestyle{empty}
  \null\vspace{\stretch{1}}
  \begin{flushright}
    \itshape
    \input{A. Frontmatter/ringraziamenti}
  \end{flushright}
  \vspace{\stretch{2.5}} \null
}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% --- DEFINZIONE MAINMATTER --- %%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\renewcommand{\mainmatter}{
    \introduzione
    \pagenumbering{arabic}   % stile numerazione delle pagine
}

%%% --- INTRODUZIONE --- %%%%
\newcommand{\introduzione}{
    \input{B. Mainmatter/introduzione}
}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% --- DEFINIZIONE BACKMATTER --- %%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\renewcommand{\backmatter}{
    \ifdefined\open \cleardoublepage \else \clearpage \fi   % if necessario per evitare errori nella numerazione delle pagine nell'intestazione
    \ifdefined\two \cleardoublepage \else \clearpage \fi    % if necessario per evitare errori nella numerazione delle pagine nell'intestazione
    \phantomsection % necessario per far funzionare hyperref
    \addcontentsline{toc}{chapter}{\bibname}    % aggiunta bibliografia nell'indice
    \bibliographystyle{erae}    % stile bibliografia
	\bibliography{bibliografia} % bibliografia
}